@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -87,7 +87,11 @@ void CSVImportExportPluginInterface::slotExportCVS()
 void CSVImportExportPluginInterface::exportToFile(QFile *file, const KContacts::Addressee::List &contacts) const
 {
     QTextStream stream(file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::System);
+#else
     stream.setCodec(QTextCodec::codecForLocale());
+#endif
 
     auto fields = KAddressBookImportExport::ContactFields::allFields();
     fields.remove(KAddressBookImportExport::ContactFields::Undefined);
@@ -155,7 +159,7 @@ void CSVImportExportPluginInterface::exportCSV()
     delete dlg;
 
     if (contacts.isEmpty()) {
-        KMessageBox::sorry(nullptr, i18n("You have not selected any contacts to export."));
+        KMessageBox::error(nullptr, i18n("You have not selected any contacts to export."));
         return;
     }
 
