@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -17,9 +17,7 @@ AttachmentListWidget::AttachmentListWidget(QWidget *parent, ButtonCode buttons,
 {
 }
 
-AttachmentListWidget::~AttachmentListWidget()
-{
-}
+AttachmentListWidget::~AttachmentListWidget() = default;
 
 void AttachmentListWidget::addNewEntry()
 {
