@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -67,9 +67,7 @@ MailMergeWidget::MailMergeWidget(QWidget *parent)
     mainLayout->addStretch();
 }
 
-MailMergeWidget::~MailMergeWidget()
-{
-}
+MailMergeWidget::~MailMergeWidget() = default;
 
 void MailMergeWidget::slotSourceChanged(int index)
 {
