@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ DKIMPolicyWidgetTest::DKIMPolicyWidgetTest(QObject *parent)
 {
 }
 
-DKIMPolicyWidgetTest::~DKIMPolicyWidgetTest()
-{
-}
+DKIMPolicyWidgetTest::~DKIMPolicyWidgetTest() = default;
 
 void DKIMPolicyWidgetTest::shouldHaveDefaultValues()
 {
