@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,9 +36,7 @@ HeaderStyleMenuTest::HeaderStyleMenuTest(QWidget *parent)
     manager->readConfig();
 }
 
-HeaderStyleMenuTest::~HeaderStyleMenuTest()
-{
-}
+HeaderStyleMenuTest::~HeaderStyleMenuTest() = default;
 
 void HeaderStyleMenuTest::styleChanged(MessageViewer::HeaderStylePlugin *plugin)
 {
