@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,9 +24,7 @@ ViewerPluginCreateTodoTest::ViewerPluginCreateTodoTest(QObject *parent)
     MessageViewer::_k_todoEditStubModel = model;
 }
 
-ViewerPluginCreateTodoTest::~ViewerPluginCreateTodoTest()
-{
-}
+ViewerPluginCreateTodoTest::~ViewerPluginCreateTodoTest() = default;
 
 void ViewerPluginCreateTodoTest::shouldCreateAction()
 {
